package com.me.pacman;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.utils.Array;

/**
 * A simple class for retrieving and saving high scores to persistent storage.
 *
 * Scores are saved in a simple text file
 */
public class HighScoreManager {

    public static final String FILE = "scores.dat";

    private FileHandle file;

    private Array<Score> scores = new Array<>(10);

    public HighScoreManager() {
        file = Gdx.files.local(FILE);
        loadScores();
    }

    private void loadScores() {
        if (!file.exists()) {
            return;
        }

        String data = file.readString();
        String[] lines = data.split("\n");

        for (String line : lines) {
            String[] parts = line.split("\t");
            scores.add(new Score(parts[0], Integer.parseInt(parts[1])));
        }
    }

    private void saveScores() {
        for (int i = 0; i < scores.size; i++) {
            Score score = scores.get(i);
            boolean append = i > 0;
            file.writeString(String.format("%s\t%d\n", score.scorer, score.score), append);
        }
    }

    private void sortScores() {
        scores.sort(Score.SCORE_SORTER);
    }

    public Score getCurrentHighScore() {
        return scores.size > 0 ? scores.get(0) : null;
    }

    public Score[] getHighScores(int count) {
        Score[] ret = new Score[Math.min(count, scores.size)];
        System.arraycopy(scores.items, 0, ret, 0, ret.length);
        return ret;
    }

    public void addScore(Score score) {
        scores.add(score);
        sortScores();
        saveScores();
    }

}
