package com.me.pacman.state;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.InputAdapter;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.math.Vector2;
import com.me.pacman.Constants;
import com.me.pacman.PacDude;
import com.me.pacman.Score;

public class HighScoresState extends State {

    public static final MenuState.BoundingBox BUTTON = new MenuState.BoundingBox(
            11 * Constants.TILE_SIZE,
            5 * Constants.TILE_SIZE,
            17 * Constants.TILE_SIZE,
            6 * Constants.TILE_SIZE);


    private Texture background;

    private boolean buttonPressed = false;


    public HighScoresState(PacDude game) {
        super(game);
    }

    @Override
    public void setup() {
        this.background = game.assets.getHighScoresBackground();
        Gdx.input.setInputProcessor(this.new Controller());
    }

    @Override
    public void render() {
        game.batch.draw(background, 0, 16);

        game.fontRenderer.setColor(Color.YELLOW);
        game.fontRenderer.draw(game.batch, "high scores", (8 * Constants.TILE_SIZE) + Constants.TILE_SIZE/2, 25 * Constants.TILE_SIZE);

        game.fontRenderer.setColor(Color.CHARTREUSE);
        game.fontRenderer.draw(game.batch, "score  name", (8 * Constants.TILE_SIZE) + Constants.TILE_SIZE/2, 22 * Constants.TILE_SIZE);

        game.fontRenderer.setColor(Color.WHITE);
        Score[] scores = game.highScores.getHighScores(10);
        for (int i = 0; i < scores.length; i++) {
            Score score = scores[i];
            game.fontRenderer.draw(game.batch, String.format("%-8d%s", score.score, score.scorer), (8 * Constants.TILE_SIZE) + Constants.TILE_SIZE/2, (18 - i) * 9);
        }

        game.fontRenderer.setColor(buttonPressed ? Color.BLUE : Color.WHITE);
        game.fontRenderer.draw(game.batch, "return", 11 * Constants.TILE_SIZE, 5 * Constants.TILE_SIZE - 1);
    }

    @Override
    public void dispose() {
        Gdx.input.setInputProcessor(null);
    }

    @Override
    public void update(float dt) {}

    private final class Controller extends InputAdapter {

        @Override
        public boolean keyDown(int keycode) {
            switch(keycode) {
                case Input.Keys.ENTER:
                case Input.Keys.BACK:
                case Input.Keys.ESCAPE:
                    game.setNextState(new MenuState(game));
                    break;
            }
            return super.keyDown(keycode);
        }

        @Override
        public boolean touchDown(int screenX, int screenY, int pointer, int button) {
            Vector2 coords = game.viewport.unproject(new Vector2(screenX, screenY));
            if (BUTTON.contains(coords)) {
                buttonPressed = true;
            }
            return true;
        }

        @Override
        public boolean touchUp(int screenX, int screenY, int pointer, int button) {
            if (!buttonPressed) {
                return true;
            }
            buttonPressed = false;

            Vector2 coords = game.viewport.unproject(new Vector2(screenX, screenY));
            if (BUTTON.contains(coords)) {
                game.setNextState(new MenuState(game));
            }

            return true;
        }

    }

}
